@@ -1,7 +1,6 @@
 # /// script
-# dependencies = [
-#   "rich",
-# ]
+# dependencies = ["rich"]
+# ///
 from rich.console import Console
 from rich.box import SIMPLE
 from rich.table import Table
@@ -18,7 +17,7 @@ for color in colors:
     table.add_row(
         color,
         *[
-            f"[{style}{color}]██████[/{style}{color}]"
+            f"[{style}{color}]▓▓▓▓▓▓[/{style}{color}]"
             for style in ["", "dim ", "bright_", "dim bright_"]
         ]
     )
